# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class LoansResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'int',
        'liquidation_price': 'Currency',
        'collateral': 'Currency',
        'collateralization_ratio': 'str',
        'loan_to_value': 'str',
        'debt': 'Currency',
        'principal': 'Currency',
        'scaled_debt': 'Currency',
        'plan': 'LoanPlan',
        'state': 'dict(str, str)',
        'updated_collateral_token_balance': 'Currency',
        'updated_debt_token_balance': 'Currency',
        'terms_and_conditions': 'BulletContent'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'liquidation_price': 'liquidationPrice',
        'collateral': 'collateral',
        'collateralization_ratio': 'collateralizationRatio',
        'loan_to_value': 'loanToValue',
        'debt': 'debt',
        'principal': 'principal',
        'scaled_debt': 'scaledDebt',
        'plan': 'plan',
        'state': 'state',
        'updated_collateral_token_balance': 'updatedCollateralTokenBalance',
        'updated_debt_token_balance': 'updatedDebtTokenBalance',
        'terms_and_conditions': 'termsAndConditions'
    }

    def __init__(self, id=None, user_id=None, liquidation_price=None, collateral=None, collateralization_ratio=None, loan_to_value=None, debt=None, principal=None, scaled_debt=None, plan=None, state=None, updated_collateral_token_balance=None, updated_debt_token_balance=None, terms_and_conditions=None, local_vars_configuration=None):  # noqa: E501
        """LoansResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._liquidation_price = None
        self._collateral = None
        self._collateralization_ratio = None
        self._loan_to_value = None
        self._debt = None
        self._principal = None
        self._scaled_debt = None
        self._plan = None
        self._state = None
        self._updated_collateral_token_balance = None
        self._updated_debt_token_balance = None
        self._terms_and_conditions = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.user_id = user_id
        self.liquidation_price = liquidation_price
        self.collateral = collateral
        self.collateralization_ratio = collateralization_ratio
        self.loan_to_value = loan_to_value
        self.debt = debt
        self.principal = principal
        self.scaled_debt = scaled_debt
        self.plan = plan
        self.state = state
        if updated_collateral_token_balance is not None:
            self.updated_collateral_token_balance = updated_collateral_token_balance
        if updated_debt_token_balance is not None:
            self.updated_debt_token_balance = updated_debt_token_balance
        if terms_and_conditions is not None:
            self.terms_and_conditions = terms_and_conditions

    @property
    def id(self):
        """Gets the id of this LoansResponse.  # noqa: E501

        Identifier for the vault.  # noqa: E501

        :return: The id of this LoansResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LoansResponse.

        Identifier for the vault.  # noqa: E501

        :param id: The id of this LoansResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this LoansResponse.  # noqa: E501

        Identifier for the user.  # noqa: E501

        :return: The user_id of this LoansResponse.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this LoansResponse.

        Identifier for the user.  # noqa: E501

        :param user_id: The user_id of this LoansResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def liquidation_price(self):
        """Gets the liquidation_price of this LoansResponse.  # noqa: E501


        :return: The liquidation_price of this LoansResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._liquidation_price

    @liquidation_price.setter
    def liquidation_price(self, liquidation_price):
        """Sets the liquidation_price of this LoansResponse.


        :param liquidation_price: The liquidation_price of this LoansResponse.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and liquidation_price is None:  # noqa: E501
            raise ValueError("Invalid value for `liquidation_price`, must not be `None`")  # noqa: E501

        self._liquidation_price = liquidation_price

    @property
    def collateral(self):
        """Gets the collateral of this LoansResponse.  # noqa: E501


        :return: The collateral of this LoansResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._collateral

    @collateral.setter
    def collateral(self, collateral):
        """Sets the collateral of this LoansResponse.


        :param collateral: The collateral of this LoansResponse.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and collateral is None:  # noqa: E501
            raise ValueError("Invalid value for `collateral`, must not be `None`")  # noqa: E501

        self._collateral = collateral

    @property
    def collateralization_ratio(self):
        """Gets the collateralization_ratio of this LoansResponse.  # noqa: E501

        The collateralization ratio of the vault.  # noqa: E501

        :return: The collateralization_ratio of this LoansResponse.  # noqa: E501
        :rtype: str
        """
        return self._collateralization_ratio

    @collateralization_ratio.setter
    def collateralization_ratio(self, collateralization_ratio):
        """Sets the collateralization_ratio of this LoansResponse.

        The collateralization ratio of the vault.  # noqa: E501

        :param collateralization_ratio: The collateralization_ratio of this LoansResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and collateralization_ratio is None:  # noqa: E501
            raise ValueError("Invalid value for `collateralization_ratio`, must not be `None`")  # noqa: E501

        self._collateralization_ratio = collateralization_ratio

    @property
    def loan_to_value(self):
        """Gets the loan_to_value of this LoansResponse.  # noqa: E501

        The loan to value of the vault.  # noqa: E501

        :return: The loan_to_value of this LoansResponse.  # noqa: E501
        :rtype: str
        """
        return self._loan_to_value

    @loan_to_value.setter
    def loan_to_value(self, loan_to_value):
        """Sets the loan_to_value of this LoansResponse.

        The loan to value of the vault.  # noqa: E501

        :param loan_to_value: The loan_to_value of this LoansResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and loan_to_value is None:  # noqa: E501
            raise ValueError("Invalid value for `loan_to_value`, must not be `None`")  # noqa: E501

        self._loan_to_value = loan_to_value

    @property
    def debt(self):
        """Gets the debt of this LoansResponse.  # noqa: E501


        :return: The debt of this LoansResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._debt

    @debt.setter
    def debt(self, debt):
        """Sets the debt of this LoansResponse.


        :param debt: The debt of this LoansResponse.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and debt is None:  # noqa: E501
            raise ValueError("Invalid value for `debt`, must not be `None`")  # noqa: E501

        self._debt = debt

    @property
    def principal(self):
        """Gets the principal of this LoansResponse.  # noqa: E501


        :return: The principal of this LoansResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._principal

    @principal.setter
    def principal(self, principal):
        """Sets the principal of this LoansResponse.


        :param principal: The principal of this LoansResponse.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and principal is None:  # noqa: E501
            raise ValueError("Invalid value for `principal`, must not be `None`")  # noqa: E501

        self._principal = principal

    @property
    def scaled_debt(self):
        """Gets the scaled_debt of this LoansResponse.  # noqa: E501


        :return: The scaled_debt of this LoansResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._scaled_debt

    @scaled_debt.setter
    def scaled_debt(self, scaled_debt):
        """Sets the scaled_debt of this LoansResponse.


        :param scaled_debt: The scaled_debt of this LoansResponse.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and scaled_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `scaled_debt`, must not be `None`")  # noqa: E501

        self._scaled_debt = scaled_debt

    @property
    def plan(self):
        """Gets the plan of this LoansResponse.  # noqa: E501


        :return: The plan of this LoansResponse.  # noqa: E501
        :rtype: LoanPlan
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this LoansResponse.


        :param plan: The plan of this LoansResponse.  # noqa: E501
        :type: LoanPlan
        """
        if self.local_vars_configuration.client_side_validation and plan is None:  # noqa: E501
            raise ValueError("Invalid value for `plan`, must not be `None`")  # noqa: E501

        self._plan = plan

    @property
    def state(self):
        """Gets the state of this LoansResponse.  # noqa: E501


        :return: The state of this LoansResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this LoansResponse.


        :param state: The state of this LoansResponse.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def updated_collateral_token_balance(self):
        """Gets the updated_collateral_token_balance of this LoansResponse.  # noqa: E501


        :return: The updated_collateral_token_balance of this LoansResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._updated_collateral_token_balance

    @updated_collateral_token_balance.setter
    def updated_collateral_token_balance(self, updated_collateral_token_balance):
        """Sets the updated_collateral_token_balance of this LoansResponse.


        :param updated_collateral_token_balance: The updated_collateral_token_balance of this LoansResponse.  # noqa: E501
        :type: Currency
        """

        self._updated_collateral_token_balance = updated_collateral_token_balance

    @property
    def updated_debt_token_balance(self):
        """Gets the updated_debt_token_balance of this LoansResponse.  # noqa: E501


        :return: The updated_debt_token_balance of this LoansResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._updated_debt_token_balance

    @updated_debt_token_balance.setter
    def updated_debt_token_balance(self, updated_debt_token_balance):
        """Sets the updated_debt_token_balance of this LoansResponse.


        :param updated_debt_token_balance: The updated_debt_token_balance of this LoansResponse.  # noqa: E501
        :type: Currency
        """

        self._updated_debt_token_balance = updated_debt_token_balance

    @property
    def terms_and_conditions(self):
        """Gets the terms_and_conditions of this LoansResponse.  # noqa: E501


        :return: The terms_and_conditions of this LoansResponse.  # noqa: E501
        :rtype: BulletContent
        """
        return self._terms_and_conditions

    @terms_and_conditions.setter
    def terms_and_conditions(self, terms_and_conditions):
        """Sets the terms_and_conditions of this LoansResponse.


        :param terms_and_conditions: The terms_and_conditions of this LoansResponse.  # noqa: E501
        :type: BulletContent
        """

        self._terms_and_conditions = terms_and_conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoansResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LoansResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class AccountStakingSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total_stake': 'dict(str, str)',
        'unclaimed_reward': 'dict(str, str)',
        'net_apy': 'str'
    }

    attribute_map = {
        'total_stake': 'totalStake',
        'unclaimed_reward': 'unclaimedReward',
        'net_apy': 'netApy'
    }

    def __init__(self, total_stake=None, unclaimed_reward=None, net_apy=None, local_vars_configuration=None):  # noqa: E501
        """AccountStakingSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._total_stake = None
        self._unclaimed_reward = None
        self._net_apy = None
        self.discriminator = None

        self.total_stake = total_stake
        self.unclaimed_reward = unclaimed_reward
        self.net_apy = net_apy

    @property
    def total_stake(self):
        """Gets the total_stake of this AccountStakingSummary.  # noqa: E501


        :return: The total_stake of this AccountStakingSummary.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_stake

    @total_stake.setter
    def total_stake(self, total_stake):
        """Sets the total_stake of this AccountStakingSummary.


        :param total_stake: The total_stake of this AccountStakingSummary.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_stake is None:  # noqa: E501
            raise ValueError("Invalid value for `total_stake`, must not be `None`")  # noqa: E501

        self._total_stake = total_stake

    @property
    def unclaimed_reward(self):
        """Gets the unclaimed_reward of this AccountStakingSummary.  # noqa: E501


        :return: The unclaimed_reward of this AccountStakingSummary.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._unclaimed_reward

    @unclaimed_reward.setter
    def unclaimed_reward(self, unclaimed_reward):
        """Sets the unclaimed_reward of this AccountStakingSummary.


        :param unclaimed_reward: The unclaimed_reward of this AccountStakingSummary.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and unclaimed_reward is None:  # noqa: E501
            raise ValueError("Invalid value for `unclaimed_reward`, must not be `None`")  # noqa: E501

        self._unclaimed_reward = unclaimed_reward

    @property
    def net_apy(self):
        """Gets the net_apy of this AccountStakingSummary.  # noqa: E501

        Net annual percentage yield in staking contract  # noqa: E501

        :return: The net_apy of this AccountStakingSummary.  # noqa: E501
        :rtype: str
        """
        return self._net_apy

    @net_apy.setter
    def net_apy(self, net_apy):
        """Sets the net_apy of this AccountStakingSummary.

        Net annual percentage yield in staking contract  # noqa: E501

        :param net_apy: The net_apy of this AccountStakingSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and net_apy is None:  # noqa: E501
            raise ValueError("Invalid value for `net_apy`, must not be `None`")  # noqa: E501

        self._net_apy = net_apy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountStakingSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountStakingSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.formatted_reserve_data import FormattedReserveData  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestFormattedReserveData(unittest.TestCase):
    """FormattedReserveData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FormattedReserveData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.formatted_reserve_data.FormattedReserveData()  # noqa: E501
        if include_optional :
            return FormattedReserveData(
                id = '0x1234567890123456789012345678901234567890:0x1234567890123456789012345678901234567890', 
                underlying_asset = zarban.service.openapi_client.models.token.Token(
                    name = 'Zar Stablecoin', 
                    symbol = 'USD', 
                    decimals = 18, 
                    address = '0x1234567890123456789012345678901234567890', 
                    logo_uri = '/assets/logos/dai.svg', 
                    chain_id = 1, 
                    persian_name = 'زر', ), 
                z_token_address = '0x1234567890123456789012345678901234567890', 
                variable_debt_token_address = '0x1234567890123456789012345678901234567890', 
                borrowing_enabled = True, 
                is_active = True, 
                is_frozen = False, 
                usage_as_collateral_enabled = True, 
                reserve_factor = '0.1', 
                base_lt_vas_collateral = '0.5', 
                reserve_liquidation_threshold = '0.6', 
                reserve_liquidation_bonus = '0.1', 
                utilization_rate = '0.5', 
                total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                total_liquidity = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                available_liquidity = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                supply_apy = '0.1', 
                supply_apr = '0.1', 
                variable_borrow_apy = '0.1', 
                variable_borrow_apr = '0.1', 
                price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}
            )
        else :
            return FormattedReserveData(
                id = '0x1234567890123456789012345678901234567890:0x1234567890123456789012345678901234567890',
                underlying_asset = zarban.service.openapi_client.models.token.Token(
                    name = 'Zar Stablecoin', 
                    symbol = 'USD', 
                    decimals = 18, 
                    address = '0x1234567890123456789012345678901234567890', 
                    logo_uri = '/assets/logos/dai.svg', 
                    chain_id = 1, 
                    persian_name = 'زر', ),
                z_token_address = '0x1234567890123456789012345678901234567890',
                variable_debt_token_address = '0x1234567890123456789012345678901234567890',
                borrowing_enabled = True,
                is_active = True,
                is_frozen = False,
                usage_as_collateral_enabled = True,
                reserve_factor = '0.1',
                base_lt_vas_collateral = '0.5',
                reserve_liquidation_threshold = '0.6',
                reserve_liquidation_bonus = '0.1',
                utilization_rate = '0.5',
                total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                total_liquidity = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                available_liquidity = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                supply_apy = '0.1',
                supply_apr = '0.1',
                variable_borrow_apy = '0.1',
                variable_borrow_apr = '0.1',
                price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
        )

    def testFormattedReserveData(self):
        """Test FormattedReserveData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.quote_request import QuoteRequest  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestQuoteRequest(unittest.TestCase):
    """QuoteRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test QuoteRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.quote_request.QuoteRequest()  # noqa: E501
        if include_optional :
            return QuoteRequest(
                request_id = 'a', 
                type = 'Classic', 
                trade_type = 'ExactInput', 
                input_token = '0x1234567890123456789012345678901234567890', 
                output_token = '0x1234567890123456789012345678901234567890', 
                amount = '123.456789', 
                recipient = 'a', 
                options = zarban.service.openapi_client.models.quote_request_options.QuoteRequestOptions(
                    dry_run = True, 
                    slippage_tolerance = '0.005', 
                    use_synthetic_quotes = True, 
                    permit_signature = 'a', 
                    permit_nonce = '0', 
                    permit_expiration = 56, 
                    permit_amount = '0', 
                    permit_sig_deadline = 56, 
                    quote_id = 'a', 
                    encoded_order = 'a', )
            )
        else :
            return QuoteRequest(
                trade_type = 'ExactInput',
                input_token = '0x1234567890123456789012345678901234567890',
                output_token = '0x1234567890123456789012345678901234567890',
                amount = '123.456789',
                recipient = 'a',
        )

    def testQuoteRequest(self):
        """Test QuoteRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class StablecoinSystemMintZarTxRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'str',
        'vault_id': 'int',
        'amount': 'str'
    }

    attribute_map = {
        'user': 'user',
        'vault_id': 'vaultId',
        'amount': 'amount'
    }

    def __init__(self, user=None, vault_id=None, amount=None, local_vars_configuration=None):  # noqa: E501
        """StablecoinSystemMintZarTxRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user = None
        self._vault_id = None
        self._amount = None
        self.discriminator = None

        self.user = user
        self.vault_id = vault_id
        if amount is not None:
            self.amount = amount

    @property
    def user(self):
        """Gets the user of this StablecoinSystemMintZarTxRequest.  # noqa: E501

        Ethereum address of the user  # noqa: E501

        :return: The user of this StablecoinSystemMintZarTxRequest.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this StablecoinSystemMintZarTxRequest.

        Ethereum address of the user  # noqa: E501

        :param user: The user of this StablecoinSystemMintZarTxRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def vault_id(self):
        """Gets the vault_id of this StablecoinSystemMintZarTxRequest.  # noqa: E501

        The ID of the vault  # noqa: E501

        :return: The vault_id of this StablecoinSystemMintZarTxRequest.  # noqa: E501
        :rtype: int
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """Sets the vault_id of this StablecoinSystemMintZarTxRequest.

        The ID of the vault  # noqa: E501

        :param vault_id: The vault_id of this StablecoinSystemMintZarTxRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and vault_id is None:  # noqa: E501
            raise ValueError("Invalid value for `vault_id`, must not be `None`")  # noqa: E501

        self._vault_id = vault_id

    @property
    def amount(self):
        """Gets the amount of this StablecoinSystemMintZarTxRequest.  # noqa: E501

        The amount of stablecoin to mint in native token units, if not provided, it will be calculated based on the available to mint amount  # noqa: E501

        :return: The amount of this StablecoinSystemMintZarTxRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this StablecoinSystemMintZarTxRequest.

        The amount of stablecoin to mint in native token units, if not provided, it will be calculated based on the available to mint amount  # noqa: E501

        :param amount: The amount of this StablecoinSystemMintZarTxRequest.  # noqa: E501
        :type: str
        """

        self._amount = amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StablecoinSystemMintZarTxRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StablecoinSystemMintZarTxRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class StablecoinSystemStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'system_surplus': 'SystemSurplus',
        'system_debt': 'SystemDebt',
        'system_debt_ceiling': 'SystemDebtCeiling',
        'system_surplus_buffer': 'SystemSurplusBuffer',
        'system_bad_debt': 'SystemBadDebt',
        'system_surplus_lot_size': 'SystemSurplusLotSize'
    }

    attribute_map = {
        'system_surplus': 'systemSurplus',
        'system_debt': 'systemDebt',
        'system_debt_ceiling': 'systemDebtCeiling',
        'system_surplus_buffer': 'systemSurplusBuffer',
        'system_bad_debt': 'systemBadDebt',
        'system_surplus_lot_size': 'systemSurplusLotSize'
    }

    def __init__(self, system_surplus=None, system_debt=None, system_debt_ceiling=None, system_surplus_buffer=None, system_bad_debt=None, system_surplus_lot_size=None, local_vars_configuration=None):  # noqa: E501
        """StablecoinSystemStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._system_surplus = None
        self._system_debt = None
        self._system_debt_ceiling = None
        self._system_surplus_buffer = None
        self._system_bad_debt = None
        self._system_surplus_lot_size = None
        self.discriminator = None

        self.system_surplus = system_surplus
        self.system_debt = system_debt
        self.system_debt_ceiling = system_debt_ceiling
        self.system_surplus_buffer = system_surplus_buffer
        self.system_bad_debt = system_bad_debt
        self.system_surplus_lot_size = system_surplus_lot_size

    @property
    def system_surplus(self):
        """Gets the system_surplus of this StablecoinSystemStats.  # noqa: E501


        :return: The system_surplus of this StablecoinSystemStats.  # noqa: E501
        :rtype: SystemSurplus
        """
        return self._system_surplus

    @system_surplus.setter
    def system_surplus(self, system_surplus):
        """Sets the system_surplus of this StablecoinSystemStats.


        :param system_surplus: The system_surplus of this StablecoinSystemStats.  # noqa: E501
        :type: SystemSurplus
        """
        if self.local_vars_configuration.client_side_validation and system_surplus is None:  # noqa: E501
            raise ValueError("Invalid value for `system_surplus`, must not be `None`")  # noqa: E501

        self._system_surplus = system_surplus

    @property
    def system_debt(self):
        """Gets the system_debt of this StablecoinSystemStats.  # noqa: E501


        :return: The system_debt of this StablecoinSystemStats.  # noqa: E501
        :rtype: SystemDebt
        """
        return self._system_debt

    @system_debt.setter
    def system_debt(self, system_debt):
        """Sets the system_debt of this StablecoinSystemStats.


        :param system_debt: The system_debt of this StablecoinSystemStats.  # noqa: E501
        :type: SystemDebt
        """
        if self.local_vars_configuration.client_side_validation and system_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `system_debt`, must not be `None`")  # noqa: E501

        self._system_debt = system_debt

    @property
    def system_debt_ceiling(self):
        """Gets the system_debt_ceiling of this StablecoinSystemStats.  # noqa: E501


        :return: The system_debt_ceiling of this StablecoinSystemStats.  # noqa: E501
        :rtype: SystemDebtCeiling
        """
        return self._system_debt_ceiling

    @system_debt_ceiling.setter
    def system_debt_ceiling(self, system_debt_ceiling):
        """Sets the system_debt_ceiling of this StablecoinSystemStats.


        :param system_debt_ceiling: The system_debt_ceiling of this StablecoinSystemStats.  # noqa: E501
        :type: SystemDebtCeiling
        """
        if self.local_vars_configuration.client_side_validation and system_debt_ceiling is None:  # noqa: E501
            raise ValueError("Invalid value for `system_debt_ceiling`, must not be `None`")  # noqa: E501

        self._system_debt_ceiling = system_debt_ceiling

    @property
    def system_surplus_buffer(self):
        """Gets the system_surplus_buffer of this StablecoinSystemStats.  # noqa: E501


        :return: The system_surplus_buffer of this StablecoinSystemStats.  # noqa: E501
        :rtype: SystemSurplusBuffer
        """
        return self._system_surplus_buffer

    @system_surplus_buffer.setter
    def system_surplus_buffer(self, system_surplus_buffer):
        """Sets the system_surplus_buffer of this StablecoinSystemStats.


        :param system_surplus_buffer: The system_surplus_buffer of this StablecoinSystemStats.  # noqa: E501
        :type: SystemSurplusBuffer
        """
        if self.local_vars_configuration.client_side_validation and system_surplus_buffer is None:  # noqa: E501
            raise ValueError("Invalid value for `system_surplus_buffer`, must not be `None`")  # noqa: E501

        self._system_surplus_buffer = system_surplus_buffer

    @property
    def system_bad_debt(self):
        """Gets the system_bad_debt of this StablecoinSystemStats.  # noqa: E501


        :return: The system_bad_debt of this StablecoinSystemStats.  # noqa: E501
        :rtype: SystemBadDebt
        """
        return self._system_bad_debt

    @system_bad_debt.setter
    def system_bad_debt(self, system_bad_debt):
        """Sets the system_bad_debt of this StablecoinSystemStats.


        :param system_bad_debt: The system_bad_debt of this StablecoinSystemStats.  # noqa: E501
        :type: SystemBadDebt
        """
        if self.local_vars_configuration.client_side_validation and system_bad_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `system_bad_debt`, must not be `None`")  # noqa: E501

        self._system_bad_debt = system_bad_debt

    @property
    def system_surplus_lot_size(self):
        """Gets the system_surplus_lot_size of this StablecoinSystemStats.  # noqa: E501


        :return: The system_surplus_lot_size of this StablecoinSystemStats.  # noqa: E501
        :rtype: SystemSurplusLotSize
        """
        return self._system_surplus_lot_size

    @system_surplus_lot_size.setter
    def system_surplus_lot_size(self, system_surplus_lot_size):
        """Sets the system_surplus_lot_size of this StablecoinSystemStats.


        :param system_surplus_lot_size: The system_surplus_lot_size of this StablecoinSystemStats.  # noqa: E501
        :type: SystemSurplusLotSize
        """
        if self.local_vars_configuration.client_side_validation and system_surplus_lot_size is None:  # noqa: E501
            raise ValueError("Invalid value for `system_surplus_lot_size`, must not be `None`")  # noqa: E501

        self._system_surplus_lot_size = system_surplus_lot_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StablecoinSystemStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StablecoinSystemStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.coin_response import CoinResponse  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestCoinResponse(unittest.TestCase):
    """CoinResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CoinResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.coin_response.CoinResponse()  # noqa: E501
        if include_optional :
            return CoinResponse(
                data = [
                    zarban.wallet.openapi_client.models.coin.Coin(
                        config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                            is_tradeable = True, 
                            withdraw_fees = {"tron":"10"}, 
                            min_withdrawal = {"tron":"10"}, 
                            needs_memo = True, ), 
                        symbol = 'USD', 
                        name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        logo_uri = '0', 
                        depositable_networks = [
                            zarban.wallet.openapi_client.models.network.Network(
                                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                logo_uri = '0', )
                            ], 
                        withdrawable_networks = [
                            zarban.wallet.openapi_client.models.network.Network(
                                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                logo_uri = '0', )
                            ], 
                        content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                            title = '0', 
                            text = '0', 
                            bullets = [
                                '0'
                                ], ), )
                    ]
            )
        else :
            return CoinResponse(
                data = [
                    zarban.wallet.openapi_client.models.coin.Coin(
                        config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                            is_tradeable = True, 
                            withdraw_fees = {"tron":"10"}, 
                            min_withdrawal = {"tron":"10"}, 
                            needs_memo = True, ), 
                        symbol = 'USD', 
                        name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        logo_uri = '0', 
                        depositable_networks = [
                            zarban.wallet.openapi_client.models.network.Network(
                                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                logo_uri = '0', )
                            ], 
                        withdrawable_networks = [
                            zarban.wallet.openapi_client.models.network.Network(
                                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                logo_uri = '0', )
                            ], 
                        content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                            title = '0', 
                            text = '0', 
                            bullets = [
                                '0'
                                ], ), )
                    ],
        )

    def testCoinResponse(self):
        """Test CoinResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.stablecoin_system_take_tx_request import StablecoinSystemTakeTxRequest  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestStablecoinSystemTakeTxRequest(unittest.TestCase):
    """StablecoinSystemTakeTxRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StablecoinSystemTakeTxRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.stablecoin_system_take_tx_request.StablecoinSystemTakeTxRequest()  # noqa: E501
        if include_optional :
            return StablecoinSystemTakeTxRequest(
                user = '0x1234567890123456789012345678901234567890', 
                auction_id = 1, 
                ilk = 'ETHA', 
                collateral_amount_upper_limit = '10000000000000000000', 
                max_acceptable_price = '10000000000000000000'
            )
        else :
            return StablecoinSystemTakeTxRequest(
                user = '0x1234567890123456789012345678901234567890',
                auction_id = 1,
                ilk = 'ETHA',
                collateral_amount_upper_limit = '10000000000000000000',
                max_acceptable_price = '10000000000000000000',
        )

    def testStablecoinSystemTakeTxRequest(self):
        """Test StablecoinSystemTakeTxRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.lendingpool_borrow_tx_response import LendingpoolBorrowTxResponse  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestLendingpoolBorrowTxResponse(unittest.TestCase):
    """LendingpoolBorrowTxResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LendingpoolBorrowTxResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.lendingpool_borrow_tx_response.LendingpoolBorrowTxResponse()  # noqa: E501
        if include_optional :
            return LendingpoolBorrowTxResponse(
                chain_activity = zarban.service.openapi_client.models.chain_activity.ChainActivity(
                    step_number = 56, 
                    number_of_steps = 56, 
                    steps = [
                        zarban.service.openapi_client.models.chain_activity_step.ChainActivityStep(
                            type = 'PreparedTx', 
                            data = null, )
                        ], ), 
                response = zarban.service.openapi_client.models.lendingpool_tx_response.LendingpoolTxResponse(
                    next_health_factor = '1.2', )
            )
        else :
            return LendingpoolBorrowTxResponse(
        )

    def testLendingpoolBorrowTxResponse(self):
        """Test LendingpoolBorrowTxResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class LoanCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'intent': 'str',
        'plan_name': 'str',
        'collateral': 'str',
        'debt': 'str',
        'symbol': 'str',
        'loan_to_value_option': 'LoanToValueOptions'
    }

    attribute_map = {
        'intent': 'intent',
        'plan_name': 'planName',
        'collateral': 'collateral',
        'debt': 'debt',
        'symbol': 'symbol',
        'loan_to_value_option': 'loanToValueOption'
    }

    def __init__(self, intent=None, plan_name=None, collateral=None, debt=None, symbol=None, loan_to_value_option=None, local_vars_configuration=None):  # noqa: E501
        """LoanCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._intent = None
        self._plan_name = None
        self._collateral = None
        self._debt = None
        self._symbol = None
        self._loan_to_value_option = None
        self.discriminator = None

        self.intent = intent
        self.plan_name = plan_name
        if collateral is not None:
            self.collateral = collateral
        if debt is not None:
            self.debt = debt
        self.symbol = symbol
        self.loan_to_value_option = loan_to_value_option

    @property
    def intent(self):
        """Gets the intent of this LoanCreateRequest.  # noqa: E501

        Intent to create a vault  # noqa: E501

        :return: The intent of this LoanCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._intent

    @intent.setter
    def intent(self, intent):
        """Sets the intent of this LoanCreateRequest.

        Intent to create a vault  # noqa: E501

        :param intent: The intent of this LoanCreateRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and intent is None:  # noqa: E501
            raise ValueError("Invalid value for `intent`, must not be `None`")  # noqa: E501
        allowed_values = ["Create", "Preview"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and intent not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `intent` ({0}), must be one of {1}"  # noqa: E501
                .format(intent, allowed_values)
            )

        self._intent = intent

    @property
    def plan_name(self):
        """Gets the plan_name of this LoanCreateRequest.  # noqa: E501

        The name of the loan plan  # noqa: E501

        :return: The plan_name of this LoanCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._plan_name

    @plan_name.setter
    def plan_name(self, plan_name):
        """Sets the plan_name of this LoanCreateRequest.

        The name of the loan plan  # noqa: E501

        :param plan_name: The plan_name of this LoanCreateRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and plan_name is None:  # noqa: E501
            raise ValueError("Invalid value for `plan_name`, must not be `None`")  # noqa: E501

        self._plan_name = plan_name

    @property
    def collateral(self):
        """Gets the collateral of this LoanCreateRequest.  # noqa: E501

        Collateral amount  # noqa: E501

        :return: The collateral of this LoanCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._collateral

    @collateral.setter
    def collateral(self, collateral):
        """Sets the collateral of this LoanCreateRequest.

        Collateral amount  # noqa: E501

        :param collateral: The collateral of this LoanCreateRequest.  # noqa: E501
        :type: str
        """

        self._collateral = collateral

    @property
    def debt(self):
        """Gets the debt of this LoanCreateRequest.  # noqa: E501

        Debt amount  # noqa: E501

        :return: The debt of this LoanCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._debt

    @debt.setter
    def debt(self, debt):
        """Sets the debt of this LoanCreateRequest.

        Debt amount  # noqa: E501

        :param debt: The debt of this LoanCreateRequest.  # noqa: E501
        :type: str
        """

        self._debt = debt

    @property
    def symbol(self):
        """Gets the symbol of this LoanCreateRequest.  # noqa: E501

        Coin symbol  # noqa: E501

        :return: The symbol of this LoanCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this LoanCreateRequest.

        Coin symbol  # noqa: E501

        :param symbol: The symbol of this LoanCreateRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and symbol is None:  # noqa: E501
            raise ValueError("Invalid value for `symbol`, must not be `None`")  # noqa: E501

        self._symbol = symbol

    @property
    def loan_to_value_option(self):
        """Gets the loan_to_value_option of this LoanCreateRequest.  # noqa: E501


        :return: The loan_to_value_option of this LoanCreateRequest.  # noqa: E501
        :rtype: LoanToValueOptions
        """
        return self._loan_to_value_option

    @loan_to_value_option.setter
    def loan_to_value_option(self, loan_to_value_option):
        """Sets the loan_to_value_option of this LoanCreateRequest.


        :param loan_to_value_option: The loan_to_value_option of this LoanCreateRequest.  # noqa: E501
        :type: LoanToValueOptions
        """
        if self.local_vars_configuration.client_side_validation and loan_to_value_option is None:  # noqa: E501
            raise ValueError("Invalid value for `loan_to_value_option`, must not be `None`")  # noqa: E501

        self._loan_to_value_option = loan_to_value_option

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoanCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LoanCreateRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.payment import Payment  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestPayment(unittest.TestCase):
    """Payment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Payment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.payment.Payment()  # noqa: E501
        if include_optional :
            return Payment(
                amount = '100.00', 
                hash = '0x1234567890abcdef', 
                url = 'https://t.me/catizenbot/gameapp?startapp=rp_1365932', 
                sender_first_name = 'John', 
                text = 'Payment for the game', 
                share_url = 'https://t.me/share/url?url=https://t.me/catizenbot/gameapp?startapp=rp_1365932&text=%F0%9F%92%B0Catizen%3A%20Unleash%2C%20Play%2C%20Earn%20-%20Where%20Every%20Game%20Leads%20to%20an%20Airdrop%20Adventure!%0A%F0%9F%8E%81Let%27s%20play-to-earn%20airdrop%20right%20now!'
            )
        else :
            return Payment(
                amount = '100.00',
                hash = '0x1234567890abcdef',
                url = 'https://t.me/catizenbot/gameapp?startapp=rp_1365932',
                sender_first_name = 'John',
                text = 'Payment for the game',
                share_url = 'https://t.me/share/url?url=https://t.me/catizenbot/gameapp?startapp=rp_1365932&text=%F0%9F%92%B0Catizen%3A%20Unleash%2C%20Play%2C%20Earn%20-%20Where%20Every%20Game%20Leads%20to%20an%20Airdrop%20Adventure!%0A%F0%9F%8E%81Let%27s%20play-to-earn%20airdrop%20right%20now!',
        )

    def testPayment(self):
        """Test Payment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.api.auth_api import AuthApi  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self):
        self.api = zarban.wallet.openapi_client.api.auth_api.AuthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_authenticate_with_telegram(self):
        """Test case for authenticate_with_telegram

        Authenticate with Telegram  # noqa: E501
        """
        pass

    def test_generate_jwt_token(self):
        """Test case for generate_jwt_token

        Generate a JWT token  # noqa: E501
        """
        pass

    def test_get_otp(self):
        """Test case for get_otp

        Get OTP  # noqa: E501
        """
        pass

    def test_login_with_email_and_password(self):
        """Test case for login_with_email_and_password

        Login with email and password  # noqa: E501
        """
        pass

    def test_signup_with_email_and_password(self):
        """Test case for signup_with_email_and_password

        signup with email and password  # noqa: E501
        """
        pass

    def test_verify_user_email(self):
        """Test case for verify_user_email

        Verify email  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.chain_activity_step_data import ChainActivityStepData  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestChainActivityStepData(unittest.TestCase):
    """ChainActivityStepData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ChainActivityStepData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.chain_activity_step_data.ChainActivityStepData()  # noqa: E501
        if include_optional :
            return ChainActivityStepData(
                type = '0', 
                label = {
                    'key' : '0'
                    }, 
                gas_use_estimate = 56, 
                gas_fee_estimate = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                method_parameters = zarban.service.openapi_client.models.method_parameters.MethodParameters(
                    to = 'a', 
                    calldata = '0', 
                    value = '0', ), 
                name = 'Permit2', 
                typed_data = zarban.service.openapi_client.models.typed_data.TypedData(
                    types = {
                        'key' : [
                            zarban.service.openapi_client.models.type.Type(
                                name = '0', 
                                type = '0', )
                            ]
                        }, 
                    primary_type = '0', 
                    domain = zarban.service.openapi_client.models.typed_data_domain.TypedDataDomain(
                        name = '0', 
                        version = '0', 
                        chain_id = '0', 
                        verifying_contract = '0', 
                        salt = '0', ), 
                    message = { }, ), 
                hash = 'a', 
                message = 'Hello, World!'
            )
        else :
            return ChainActivityStepData(
                type = '0',
                label = {
                    'key' : '0'
                    },
                gas_use_estimate = 56,
                gas_fee_estimate = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                method_parameters = zarban.service.openapi_client.models.method_parameters.MethodParameters(
                    to = 'a', 
                    calldata = '0', 
                    value = '0', ),
                name = 'Permit2',
                typed_data = zarban.service.openapi_client.models.typed_data.TypedData(
                    types = {
                        'key' : [
                            zarban.service.openapi_client.models.type.Type(
                                name = '0', 
                                type = '0', )
                            ]
                        }, 
                    primary_type = '0', 
                    domain = zarban.service.openapi_client.models.typed_data_domain.TypedDataDomain(
                        name = '0', 
                        version = '0', 
                        chain_id = '0', 
                        verifying_contract = '0', 
                        salt = '0', ), 
                    message = { }, ),
                hash = 'a',
                message = 'Hello, World!',
        )

    def testChainActivityStepData(self):
        """Test ChainActivityStepData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class SwapResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'trade_type': 'str',
        '_in': 'Symbol',
        'out': 'Symbol',
        'amount': 'str',
        'quote': 'str',
        'rate': 'str',
        'input_balance_after_swap': 'str',
        'output_balance_after_swap': 'str',
        'created_at': 'Timestamp',
        'expires_at': 'Timestamp',
        'executed_at': 'Timestamp',
        'value': 'Currency'
    }

    attribute_map = {
        'id': 'id',
        'trade_type': 'tradeType',
        '_in': 'in',
        'out': 'out',
        'amount': 'amount',
        'quote': 'quote',
        'rate': 'rate',
        'input_balance_after_swap': 'inputBalanceAfterSwap',
        'output_balance_after_swap': 'outputBalanceAfterSwap',
        'created_at': 'createdAt',
        'expires_at': 'expiresAt',
        'executed_at': 'executedAt',
        'value': 'value'
    }

    def __init__(self, id=None, trade_type=None, _in=None, out=None, amount=None, quote=None, rate=None, input_balance_after_swap=None, output_balance_after_swap=None, created_at=None, expires_at=None, executed_at=None, value=None, local_vars_configuration=None):  # noqa: E501
        """SwapResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._trade_type = None
        self.__in = None
        self._out = None
        self._amount = None
        self._quote = None
        self._rate = None
        self._input_balance_after_swap = None
        self._output_balance_after_swap = None
        self._created_at = None
        self._expires_at = None
        self._executed_at = None
        self._value = None
        self.discriminator = None

        self.id = id
        self.trade_type = trade_type
        self._in = _in
        self.out = out
        self.amount = amount
        self.quote = quote
        self.rate = rate
        if input_balance_after_swap is not None:
            self.input_balance_after_swap = input_balance_after_swap
        if output_balance_after_swap is not None:
            self.output_balance_after_swap = output_balance_after_swap
        self.created_at = created_at
        self.expires_at = expires_at
        if executed_at is not None:
            self.executed_at = executed_at
        self.value = value

    @property
    def id(self):
        """Gets the id of this SwapResponse.  # noqa: E501


        :return: The id of this SwapResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SwapResponse.


        :param id: The id of this SwapResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def trade_type(self):
        """Gets the trade_type of this SwapResponse.  # noqa: E501


        :return: The trade_type of this SwapResponse.  # noqa: E501
        :rtype: str
        """
        return self._trade_type

    @trade_type.setter
    def trade_type(self, trade_type):
        """Sets the trade_type of this SwapResponse.


        :param trade_type: The trade_type of this SwapResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trade_type is None:  # noqa: E501
            raise ValueError("Invalid value for `trade_type`, must not be `None`")  # noqa: E501
        allowed_values = ["ExactInput", "ExactOutput"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and trade_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `trade_type` ({0}), must be one of {1}"  # noqa: E501
                .format(trade_type, allowed_values)
            )

        self._trade_type = trade_type

    @property
    def _in(self):
        """Gets the _in of this SwapResponse.  # noqa: E501


        :return: The _in of this SwapResponse.  # noqa: E501
        :rtype: Symbol
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this SwapResponse.


        :param _in: The _in of this SwapResponse.  # noqa: E501
        :type: Symbol
        """
        if self.local_vars_configuration.client_side_validation and _in is None:  # noqa: E501
            raise ValueError("Invalid value for `_in`, must not be `None`")  # noqa: E501

        self.__in = _in

    @property
    def out(self):
        """Gets the out of this SwapResponse.  # noqa: E501


        :return: The out of this SwapResponse.  # noqa: E501
        :rtype: Symbol
        """
        return self._out

    @out.setter
    def out(self, out):
        """Sets the out of this SwapResponse.


        :param out: The out of this SwapResponse.  # noqa: E501
        :type: Symbol
        """
        if self.local_vars_configuration.client_side_validation and out is None:  # noqa: E501
            raise ValueError("Invalid value for `out`, must not be `None`")  # noqa: E501

        self._out = out

    @property
    def amount(self):
        """Gets the amount of this SwapResponse.  # noqa: E501


        :return: The amount of this SwapResponse.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this SwapResponse.


        :param amount: The amount of this SwapResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def quote(self):
        """Gets the quote of this SwapResponse.  # noqa: E501


        :return: The quote of this SwapResponse.  # noqa: E501
        :rtype: str
        """
        return self._quote

    @quote.setter
    def quote(self, quote):
        """Sets the quote of this SwapResponse.


        :param quote: The quote of this SwapResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and quote is None:  # noqa: E501
            raise ValueError("Invalid value for `quote`, must not be `None`")  # noqa: E501

        self._quote = quote

    @property
    def rate(self):
        """Gets the rate of this SwapResponse.  # noqa: E501


        :return: The rate of this SwapResponse.  # noqa: E501
        :rtype: str
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this SwapResponse.


        :param rate: The rate of this SwapResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and rate is None:  # noqa: E501
            raise ValueError("Invalid value for `rate`, must not be `None`")  # noqa: E501

        self._rate = rate

    @property
    def input_balance_after_swap(self):
        """Gets the input_balance_after_swap of this SwapResponse.  # noqa: E501


        :return: The input_balance_after_swap of this SwapResponse.  # noqa: E501
        :rtype: str
        """
        return self._input_balance_after_swap

    @input_balance_after_swap.setter
    def input_balance_after_swap(self, input_balance_after_swap):
        """Sets the input_balance_after_swap of this SwapResponse.


        :param input_balance_after_swap: The input_balance_after_swap of this SwapResponse.  # noqa: E501
        :type: str
        """

        self._input_balance_after_swap = input_balance_after_swap

    @property
    def output_balance_after_swap(self):
        """Gets the output_balance_after_swap of this SwapResponse.  # noqa: E501


        :return: The output_balance_after_swap of this SwapResponse.  # noqa: E501
        :rtype: str
        """
        return self._output_balance_after_swap

    @output_balance_after_swap.setter
    def output_balance_after_swap(self, output_balance_after_swap):
        """Sets the output_balance_after_swap of this SwapResponse.


        :param output_balance_after_swap: The output_balance_after_swap of this SwapResponse.  # noqa: E501
        :type: str
        """

        self._output_balance_after_swap = output_balance_after_swap

    @property
    def created_at(self):
        """Gets the created_at of this SwapResponse.  # noqa: E501


        :return: The created_at of this SwapResponse.  # noqa: E501
        :rtype: Timestamp
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SwapResponse.


        :param created_at: The created_at of this SwapResponse.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def expires_at(self):
        """Gets the expires_at of this SwapResponse.  # noqa: E501


        :return: The expires_at of this SwapResponse.  # noqa: E501
        :rtype: Timestamp
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this SwapResponse.


        :param expires_at: The expires_at of this SwapResponse.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and expires_at is None:  # noqa: E501
            raise ValueError("Invalid value for `expires_at`, must not be `None`")  # noqa: E501

        self._expires_at = expires_at

    @property
    def executed_at(self):
        """Gets the executed_at of this SwapResponse.  # noqa: E501


        :return: The executed_at of this SwapResponse.  # noqa: E501
        :rtype: Timestamp
        """
        return self._executed_at

    @executed_at.setter
    def executed_at(self, executed_at):
        """Sets the executed_at of this SwapResponse.


        :param executed_at: The executed_at of this SwapResponse.  # noqa: E501
        :type: Timestamp
        """

        self._executed_at = executed_at

    @property
    def value(self):
        """Gets the value of this SwapResponse.  # noqa: E501


        :return: The value of this SwapResponse.  # noqa: E501
        :rtype: Currency
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SwapResponse.


        :param value: The value of this SwapResponse.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwapResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SwapResponse):
            return True

        return self.to_dict() != other.to_dict()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="zarban",
    version="0.5.1",
    author="Zarban",
    author_email="info@zarban.io",
    description="Python SDK for Zarban",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/zarbanio/zarban-py",
    project_urls={
        "Homepage": "https://zarban.io",
        "Documentation": "https://docs.zarban.io",
        "Source Code": "https://github.com/zarbanio/zarban-py",
        "GitHub": "https://github.com/zarbanio",
        "Instagram": "https://www.instagram.com/zarban_io/",
        "X": "https://twitter.com/ZarbanProtocol",
    },
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    include_package_data=True,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    python_requires=">=3.7",
    install_requires=[
        "requests>=2.25.1",
        "web3",
        "python-dateutil",
        "requests",
        # Add other dependencies here
    ],
)



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.profile_response import ProfileResponse  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestProfileResponse(unittest.TestCase):
    """ProfileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProfileResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.profile_response.ProfileResponse()  # noqa: E501
        if include_optional :
            return ProfileResponse(
                referral = zarban.wallet.openapi_client.models.referral.Referral(
                    id = 56, 
                    referrer_id = 56, 
                    name = '0', 
                    usage_limit = 56, 
                    usage_count = 56, 
                    created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    link = 'https://t.me/zarbanwalletbot?start=referral-29', 
                    share_url = 'https://t.me/zarbanwalletbot?start=referral-29', ), 
                points = 56, 
                user = zarban.wallet.openapi_client.models.user.User(
                    first_name = 'John', 
                    last_name = 'Doe', 
                    email = '0', 
                    username = '0', 
                    phone = '0', 
                    is_email_verified = True, 
                    is_phone_verified = True, 
                    is_kyc_verified = True, 
                    is_child = True, 
                    is_super_user = True, 
                    is_admin = True, 
                    telegram = zarban.wallet.openapi_client.models.telegram_profile.TelegramProfile(
                        username = '0', 
                        first_name = '0', 
                        last_name = '0', 
                        photo_url = '0', ), ), 
                bank_info = [
                    zarban.wallet.openapi_client.models.bank_info.BankInfo(
                        bank_name = 'Bank Melli', 
                        card_number = '1234567890', 
                        iban = 'IR1234567890', )
                    ]
            )
        else :
            return ProfileResponse(
                referral = zarban.wallet.openapi_client.models.referral.Referral(
                    id = 56, 
                    referrer_id = 56, 
                    name = '0', 
                    usage_limit = 56, 
                    usage_count = 56, 
                    created_at = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    link = 'https://t.me/zarbanwalletbot?start=referral-29', 
                    share_url = 'https://t.me/zarbanwalletbot?start=referral-29', ),
                points = 56,
                user = zarban.wallet.openapi_client.models.user.User(
                    first_name = 'John', 
                    last_name = 'Doe', 
                    email = '0', 
                    username = '0', 
                    phone = '0', 
                    is_email_verified = True, 
                    is_phone_verified = True, 
                    is_kyc_verified = True, 
                    is_child = True, 
                    is_super_user = True, 
                    is_admin = True, 
                    telegram = zarban.wallet.openapi_client.models.telegram_profile.TelegramProfile(
                        username = '0', 
                        first_name = '0', 
                        last_name = '0', 
                        photo_url = '0', ), ),
                bank_info = [
                    zarban.wallet.openapi_client.models.bank_info.BankInfo(
                        bank_name = 'Bank Melli', 
                        card_number = '1234567890', 
                        iban = 'IR1234567890', )
                    ],
        )

    def testProfileResponse(self):
        """Test ProfileResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class Account(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'points': 'int',
        'address': 'str',
        'wallet_balance': 'WalletBalance',
        'net_worth': 'dict(str, str)',
        'total_debt': 'dict(str, str)',
        'total_deposits': 'dict(str, str)',
        'lendingpool_summary': 'AccountLendingpoolSummary',
        'stabelcoin_system_summary': 'AccountStablecoinSystemSummary',
        'staking_summary': 'AccountStakingSummary'
    }

    attribute_map = {
        'points': 'points',
        'address': 'address',
        'wallet_balance': 'walletBalance',
        'net_worth': 'netWorth',
        'total_debt': 'totalDebt',
        'total_deposits': 'totalDeposits',
        'lendingpool_summary': 'lendingpoolSummary',
        'stabelcoin_system_summary': 'stabelcoinSystemSummary',
        'staking_summary': 'stakingSummary'
    }

    def __init__(self, points=None, address=None, wallet_balance=None, net_worth=None, total_debt=None, total_deposits=None, lendingpool_summary=None, stabelcoin_system_summary=None, staking_summary=None, local_vars_configuration=None):  # noqa: E501
        """Account - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._points = None
        self._address = None
        self._wallet_balance = None
        self._net_worth = None
        self._total_debt = None
        self._total_deposits = None
        self._lendingpool_summary = None
        self._stabelcoin_system_summary = None
        self._staking_summary = None
        self.discriminator = None

        self.points = points
        self.address = address
        self.wallet_balance = wallet_balance
        self.net_worth = net_worth
        self.total_debt = total_debt
        self.total_deposits = total_deposits
        self.lendingpool_summary = lendingpool_summary
        self.stabelcoin_system_summary = stabelcoin_system_summary
        self.staking_summary = staking_summary

    @property
    def points(self):
        """Gets the points of this Account.  # noqa: E501

        The number of points the account has.  # noqa: E501

        :return: The points of this Account.  # noqa: E501
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this Account.

        The number of points the account has.  # noqa: E501

        :param points: The points of this Account.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and points is None:  # noqa: E501
            raise ValueError("Invalid value for `points`, must not be `None`")  # noqa: E501

        self._points = points

    @property
    def address(self):
        """Gets the address of this Account.  # noqa: E501

        Ethereum address of the account  # noqa: E501

        :return: The address of this Account.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Account.

        Ethereum address of the account  # noqa: E501

        :param address: The address of this Account.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address is None:  # noqa: E501
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def wallet_balance(self):
        """Gets the wallet_balance of this Account.  # noqa: E501


        :return: The wallet_balance of this Account.  # noqa: E501
        :rtype: WalletBalance
        """
        return self._wallet_balance

    @wallet_balance.setter
    def wallet_balance(self, wallet_balance):
        """Sets the wallet_balance of this Account.


        :param wallet_balance: The wallet_balance of this Account.  # noqa: E501
        :type: WalletBalance
        """
        if self.local_vars_configuration.client_side_validation and wallet_balance is None:  # noqa: E501
            raise ValueError("Invalid value for `wallet_balance`, must not be `None`")  # noqa: E501

        self._wallet_balance = wallet_balance

    @property
    def net_worth(self):
        """Gets the net_worth of this Account.  # noqa: E501


        :return: The net_worth of this Account.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._net_worth

    @net_worth.setter
    def net_worth(self, net_worth):
        """Sets the net_worth of this Account.


        :param net_worth: The net_worth of this Account.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and net_worth is None:  # noqa: E501
            raise ValueError("Invalid value for `net_worth`, must not be `None`")  # noqa: E501

        self._net_worth = net_worth

    @property
    def total_debt(self):
        """Gets the total_debt of this Account.  # noqa: E501


        :return: The total_debt of this Account.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_debt

    @total_debt.setter
    def total_debt(self, total_debt):
        """Sets the total_debt of this Account.


        :param total_debt: The total_debt of this Account.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `total_debt`, must not be `None`")  # noqa: E501

        self._total_debt = total_debt

    @property
    def total_deposits(self):
        """Gets the total_deposits of this Account.  # noqa: E501


        :return: The total_deposits of this Account.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_deposits

    @total_deposits.setter
    def total_deposits(self, total_deposits):
        """Sets the total_deposits of this Account.


        :param total_deposits: The total_deposits of this Account.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_deposits is None:  # noqa: E501
            raise ValueError("Invalid value for `total_deposits`, must not be `None`")  # noqa: E501

        self._total_deposits = total_deposits

    @property
    def lendingpool_summary(self):
        """Gets the lendingpool_summary of this Account.  # noqa: E501


        :return: The lendingpool_summary of this Account.  # noqa: E501
        :rtype: AccountLendingpoolSummary
        """
        return self._lendingpool_summary

    @lendingpool_summary.setter
    def lendingpool_summary(self, lendingpool_summary):
        """Sets the lendingpool_summary of this Account.


        :param lendingpool_summary: The lendingpool_summary of this Account.  # noqa: E501
        :type: AccountLendingpoolSummary
        """
        if self.local_vars_configuration.client_side_validation and lendingpool_summary is None:  # noqa: E501
            raise ValueError("Invalid value for `lendingpool_summary`, must not be `None`")  # noqa: E501

        self._lendingpool_summary = lendingpool_summary

    @property
    def stabelcoin_system_summary(self):
        """Gets the stabelcoin_system_summary of this Account.  # noqa: E501


        :return: The stabelcoin_system_summary of this Account.  # noqa: E501
        :rtype: AccountStablecoinSystemSummary
        """
        return self._stabelcoin_system_summary

    @stabelcoin_system_summary.setter
    def stabelcoin_system_summary(self, stabelcoin_system_summary):
        """Sets the stabelcoin_system_summary of this Account.


        :param stabelcoin_system_summary: The stabelcoin_system_summary of this Account.  # noqa: E501
        :type: AccountStablecoinSystemSummary
        """
        if self.local_vars_configuration.client_side_validation and stabelcoin_system_summary is None:  # noqa: E501
            raise ValueError("Invalid value for `stabelcoin_system_summary`, must not be `None`")  # noqa: E501

        self._stabelcoin_system_summary = stabelcoin_system_summary

    @property
    def staking_summary(self):
        """Gets the staking_summary of this Account.  # noqa: E501


        :return: The staking_summary of this Account.  # noqa: E501
        :rtype: AccountStakingSummary
        """
        return self._staking_summary

    @staking_summary.setter
    def staking_summary(self, staking_summary):
        """Sets the staking_summary of this Account.


        :param staking_summary: The staking_summary of this Account.  # noqa: E501
        :type: AccountStakingSummary
        """
        if self.local_vars_configuration.client_side_validation and staking_summary is None:  # noqa: E501
            raise ValueError("Invalid value for `staking_summary`, must not be `None`")  # noqa: E501

        self._staking_summary = staking_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Account):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class LoanPlan(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'min_collateralization_ratio': 'str',
        'acceptable_coins': 'list[Coin]',
        'fee': 'str',
        'max_debt': 'Currency',
        'min_debt': 'Currency',
        'loan_to_value_options': 'list[DetailedLoanToValueOptions]'
    }

    attribute_map = {
        'name': 'name',
        'min_collateralization_ratio': 'minCollateralizationRatio',
        'acceptable_coins': 'acceptableCoins',
        'fee': 'fee',
        'max_debt': 'maxDebt',
        'min_debt': 'minDebt',
        'loan_to_value_options': 'loanToValueOptions'
    }

    def __init__(self, name=None, min_collateralization_ratio=None, acceptable_coins=None, fee=None, max_debt=None, min_debt=None, loan_to_value_options=None, local_vars_configuration=None):  # noqa: E501
        """LoanPlan - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._min_collateralization_ratio = None
        self._acceptable_coins = None
        self._fee = None
        self._max_debt = None
        self._min_debt = None
        self._loan_to_value_options = None
        self.discriminator = None

        self.name = name
        self.min_collateralization_ratio = min_collateralization_ratio
        self.acceptable_coins = acceptable_coins
        self.fee = fee
        self.max_debt = max_debt
        self.min_debt = min_debt
        self.loan_to_value_options = loan_to_value_options

    @property
    def name(self):
        """Gets the name of this LoanPlan.  # noqa: E501

        The name of the loan plan  # noqa: E501

        :return: The name of this LoanPlan.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LoanPlan.

        The name of the loan plan  # noqa: E501

        :param name: The name of this LoanPlan.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def min_collateralization_ratio(self):
        """Gets the min_collateralization_ratio of this LoanPlan.  # noqa: E501

        The minimum collateralization ratio of the loan plan  # noqa: E501

        :return: The min_collateralization_ratio of this LoanPlan.  # noqa: E501
        :rtype: str
        """
        return self._min_collateralization_ratio

    @min_collateralization_ratio.setter
    def min_collateralization_ratio(self, min_collateralization_ratio):
        """Sets the min_collateralization_ratio of this LoanPlan.

        The minimum collateralization ratio of the loan plan  # noqa: E501

        :param min_collateralization_ratio: The min_collateralization_ratio of this LoanPlan.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and min_collateralization_ratio is None:  # noqa: E501
            raise ValueError("Invalid value for `min_collateralization_ratio`, must not be `None`")  # noqa: E501

        self._min_collateralization_ratio = min_collateralization_ratio

    @property
    def acceptable_coins(self):
        """Gets the acceptable_coins of this LoanPlan.  # noqa: E501


        :return: The acceptable_coins of this LoanPlan.  # noqa: E501
        :rtype: list[Coin]
        """
        return self._acceptable_coins

    @acceptable_coins.setter
    def acceptable_coins(self, acceptable_coins):
        """Sets the acceptable_coins of this LoanPlan.


        :param acceptable_coins: The acceptable_coins of this LoanPlan.  # noqa: E501
        :type: list[Coin]
        """
        if self.local_vars_configuration.client_side_validation and acceptable_coins is None:  # noqa: E501
            raise ValueError("Invalid value for `acceptable_coins`, must not be `None`")  # noqa: E501

        self._acceptable_coins = acceptable_coins

    @property
    def fee(self):
        """Gets the fee of this LoanPlan.  # noqa: E501

        The annual fee of the loan plan  # noqa: E501

        :return: The fee of this LoanPlan.  # noqa: E501
        :rtype: str
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this LoanPlan.

        The annual fee of the loan plan  # noqa: E501

        :param fee: The fee of this LoanPlan.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and fee is None:  # noqa: E501
            raise ValueError("Invalid value for `fee`, must not be `None`")  # noqa: E501

        self._fee = fee

    @property
    def max_debt(self):
        """Gets the max_debt of this LoanPlan.  # noqa: E501


        :return: The max_debt of this LoanPlan.  # noqa: E501
        :rtype: Currency
        """
        return self._max_debt

    @max_debt.setter
    def max_debt(self, max_debt):
        """Sets the max_debt of this LoanPlan.


        :param max_debt: The max_debt of this LoanPlan.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and max_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `max_debt`, must not be `None`")  # noqa: E501

        self._max_debt = max_debt

    @property
    def min_debt(self):
        """Gets the min_debt of this LoanPlan.  # noqa: E501


        :return: The min_debt of this LoanPlan.  # noqa: E501
        :rtype: Currency
        """
        return self._min_debt

    @min_debt.setter
    def min_debt(self, min_debt):
        """Sets the min_debt of this LoanPlan.


        :param min_debt: The min_debt of this LoanPlan.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and min_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `min_debt`, must not be `None`")  # noqa: E501

        self._min_debt = min_debt

    @property
    def loan_to_value_options(self):
        """Gets the loan_to_value_options of this LoanPlan.  # noqa: E501


        :return: The loan_to_value_options of this LoanPlan.  # noqa: E501
        :rtype: list[DetailedLoanToValueOptions]
        """
        return self._loan_to_value_options

    @loan_to_value_options.setter
    def loan_to_value_options(self, loan_to_value_options):
        """Sets the loan_to_value_options of this LoanPlan.


        :param loan_to_value_options: The loan_to_value_options of this LoanPlan.  # noqa: E501
        :type: list[DetailedLoanToValueOptions]
        """
        if self.local_vars_configuration.client_side_validation and loan_to_value_options is None:  # noqa: E501
            raise ValueError("Invalid value for `loan_to_value_options`, must not be `None`")  # noqa: E501

        self._loan_to_value_options = loan_to_value_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoanPlan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LoanPlan):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.order_info import OrderInfo  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestOrderInfo(unittest.TestCase):
    """OrderInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OrderInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.order_info.OrderInfo()  # noqa: E501
        if include_optional :
            return OrderInfo(
                chain_id = 56, 
                permit2_address = 'a', 
                reactor = 'a', 
                swapper = 'a', 
                nonce = '0', 
                deadline = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                additional_validation_contract = 'a', 
                additional_validation_data = 'a', 
                decay_start_time = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                decay_end_time = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                exclusive_filler = 'a', 
                exclusivity_override_bps = 56, 
                input = zarban.service.openapi_client.models.dutch_amount.DutchAmount(
                    token = zarban.service.openapi_client.models.token.Token(
                        name = 'Zar Stablecoin', 
                        symbol = 'USD', 
                        decimals = 18, 
                        address = '0x1234567890123456789012345678901234567890', 
                        logo_uri = '/assets/logos/dai.svg', 
                        chain_id = 1, 
                        persian_name = 'زر', ), 
                    start_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    end_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    recipient = 'a', ), 
                outputs = [
                    zarban.service.openapi_client.models.dutch_amount.DutchAmount(
                        token = zarban.service.openapi_client.models.token.Token(
                            name = 'Zar Stablecoin', 
                            symbol = 'USD', 
                            decimals = 18, 
                            address = '0x1234567890123456789012345678901234567890', 
                            logo_uri = '/assets/logos/dai.svg', 
                            chain_id = 1, 
                            persian_name = 'زر', ), 
                        start_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        end_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        recipient = 'a', )
                    ]
            )
        else :
            return OrderInfo(
                chain_id = 56,
                permit2_address = 'a',
                reactor = 'a',
                swapper = 'a',
                nonce = '0',
                deadline = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
                additional_validation_contract = 'a',
                additional_validation_data = 'a',
                decay_start_time = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
                decay_end_time = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
                exclusive_filler = 'a',
                exclusivity_override_bps = 56,
                input = zarban.service.openapi_client.models.dutch_amount.DutchAmount(
                    token = zarban.service.openapi_client.models.token.Token(
                        name = 'Zar Stablecoin', 
                        symbol = 'USD', 
                        decimals = 18, 
                        address = '0x1234567890123456789012345678901234567890', 
                        logo_uri = '/assets/logos/dai.svg', 
                        chain_id = 1, 
                        persian_name = 'زر', ), 
                    start_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    end_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    recipient = 'a', ),
                outputs = [
                    zarban.service.openapi_client.models.dutch_amount.DutchAmount(
                        token = zarban.service.openapi_client.models.token.Token(
                            name = 'Zar Stablecoin', 
                            symbol = 'USD', 
                            decimals = 18, 
                            address = '0x1234567890123456789012345678901234567890', 
                            logo_uri = '/assets/logos/dai.svg', 
                            chain_id = 1, 
                            persian_name = 'زر', ), 
                        start_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        end_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        recipient = 'a', )
                    ],
        )

    def testOrderInfo(self):
        """Test OrderInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.vault import Vault  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestVault(unittest.TestCase):
    """Vault unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Vault
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.vault.Vault()  # noqa: E501
        if include_optional :
            return Vault(
                id = 1, 
                owner = '0x1234567890123456789012345678901234567890', 
                urn = '0x1234567890123456789012345678901234567890', 
                liquidation_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                collateral_locked = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                collateralization_ratio = '1.5', 
                loan_to_value = '0.5', 
                debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                available_to_withdraw = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                available_to_mint = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                ilk = zarban.service.openapi_client.models.ilk.Ilk(
                    name = '0', 
                    symbol = 'USD', 
                    minimum_collateralization_ratio = '0', 
                    maximum_loan_to_value = '0', 
                    liquidation_penalty = '0', 
                    debt_ceiling = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    annual_stability_fee = '0', 
                    dust_limit = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    next_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    join = '0', 
                    median = '0', 
                    gem = '0', 
                    clipper = '0', 
                    pip = '0', 
                    hole = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    dirt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, )
            )
        else :
            return Vault(
                id = 1,
                owner = '0x1234567890123456789012345678901234567890',
                urn = '0x1234567890123456789012345678901234567890',
                liquidation_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                collateral_locked = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                collateralization_ratio = '1.5',
                loan_to_value = '0.5',
                debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                available_to_withdraw = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                available_to_mint = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                ilk = zarban.service.openapi_client.models.ilk.Ilk(
                    name = '0', 
                    symbol = 'USD', 
                    minimum_collateralization_ratio = '0', 
                    maximum_loan_to_value = '0', 
                    liquidation_penalty = '0', 
                    debt_ceiling = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    annual_stability_fee = '0', 
                    dust_limit = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    next_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    join = '0', 
                    median = '0', 
                    gem = '0', 
                    clipper = '0', 
                    pip = '0', 
                    hole = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    dirt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, ),
        )

    def testVault(self):
        """Test Vault"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.extended_event import ExtendedEvent  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestExtendedEvent(unittest.TestCase):
    """ExtendedEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ExtendedEvent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.extended_event.ExtendedEvent()  # noqa: E501
        if include_optional :
            return ExtendedEvent(
                domain = 'stableCoinSystem', 
                id = 56, 
                name = 'VaultRepay', 
                raw = zarban.service.openapi_client.models.log.Log(
                    name = '0', 
                    contract = '0', 
                    timestamp = zarban.service.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    address = '0', 
                    block_number = 56, 
                    tx_hash = '0', 
                    block_hash = '0', 
                    index = 56, 
                    topics = [
                        '0x1234567890abcdef1234567abcdef'
                        ], 
                    data = '0x1234567890abcdef1234567abcdef', 
                    decoded = {
                        'key' : '0x1234567890abcdef1234567abcdef'
                        }, ), 
                type = 'executive', 
                payload = { }
            )
        else :
            return ExtendedEvent(
                domain = 'stableCoinSystem',
                id = 56,
                name = 'VaultRepay',
                raw = zarban.service.openapi_client.models.log.Log(
                    name = '0', 
                    contract = '0', 
                    timestamp = zarban.service.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    address = '0', 
                    block_number = 56, 
                    tx_hash = '0', 
                    block_hash = '0', 
                    index = 56, 
                    topics = [
                        '0x1234567890abcdef1234567abcdef'
                        ], 
                    data = '0x1234567890abcdef1234567abcdef', 
                    decoded = {
                        'key' : '0x1234567890abcdef1234567abcdef'
                        }, ),
                type = 'executive',
                payload = { },
        )

    def testExtendedEvent(self):
        """Test ExtendedEvent"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from zarban.wallet.openapi_client.api.auth_api import AuthApi
from zarban.wallet.openapi_client.api.balance_api import BalanceApi
from zarban.wallet.openapi_client.api.coins_api import CoinsApi
from zarban.wallet.openapi_client.api.deposit_api import DepositApi
from zarban.wallet.openapi_client.api.health_api import HealthApi
from zarban.wallet.openapi_client.api.loans_api import LoansApi
from zarban.wallet.openapi_client.api.payment_api import PaymentApi
from zarban.wallet.openapi_client.api.points_api import PointsApi
from zarban.wallet.openapi_client.api.redemptions_api import RedemptionsApi
from zarban.wallet.openapi_client.api.referrals_api import ReferralsApi
from zarban.wallet.openapi_client.api.swap_api import SwapApi
from zarban.wallet.openapi_client.api.tasks_api import TasksApi
from zarban.wallet.openapi_client.api.transactions_api import TransactionsApi
from zarban.wallet.openapi_client.api.user_api import UserApi
from zarban.wallet.openapi_client.api.withdraw_api import WithdrawApi

# import ApiClient
from zarban.wallet.openapi_client.api_client import ApiClient
from zarban.wallet.openapi_client.configuration import Configuration
from zarban.wallet.openapi_client.exceptions import OpenApiException
from zarban.wallet.openapi_client.exceptions import ApiTypeError
from zarban.wallet.openapi_client.exceptions import ApiValueError
from zarban.wallet.openapi_client.exceptions import ApiKeyError
from zarban.wallet.openapi_client.exceptions import ApiException
# import models into sdk package
from zarban.wallet.openapi_client.models.admin_redemption_update_request import AdminRedemptionUpdateRequest
from zarban.wallet.openapi_client.models.auth_telegram_request import AuthTelegramRequest
from zarban.wallet.openapi_client.models.balance import Balance
from zarban.wallet.openapi_client.models.bank_info import BankInfo
from zarban.wallet.openapi_client.models.bullet_content import BulletContent
from zarban.wallet.openapi_client.models.coin import Coin
from zarban.wallet.openapi_client.models.coin_config import CoinConfig
from zarban.wallet.openapi_client.models.coin_response import CoinResponse
from zarban.wallet.openapi_client.models.create_child_user_request import CreateChildUserRequest
from zarban.wallet.openapi_client.models.currency import Currency
from zarban.wallet.openapi_client.models.deposit_response import DepositResponse
from zarban.wallet.openapi_client.models.detailed_loan_to_value_options import DetailedLoanToValueOptions
from zarban.wallet.openapi_client.models.email_otp_submit_request import EmailOtpSubmitRequest
from zarban.wallet.openapi_client.models.error import Error
from zarban.wallet.openapi_client.models.error_detail import ErrorDetail
from zarban.wallet.openapi_client.models.external_transaction import ExternalTransaction
from zarban.wallet.openapi_client.models.friend_points import FriendPoints
from zarban.wallet.openapi_client.models.friend_points_response import FriendPointsResponse
from zarban.wallet.openapi_client.models.health_status import HealthStatus
from zarban.wallet.openapi_client.models.jwt_response import JwtResponse
from zarban.wallet.openapi_client.models.kyc_confirm_request import KycConfirmRequest
from zarban.wallet.openapi_client.models.kyc_request import KycRequest
from zarban.wallet.openapi_client.models.kyc_response import KycResponse
from zarban.wallet.openapi_client.models.loan_create_request import LoanCreateRequest
from zarban.wallet.openapi_client.models.loan_plan import LoanPlan
from zarban.wallet.openapi_client.models.loan_plan_response import LoanPlanResponse
from zarban.wallet.openapi_client.models.loan_to_value_options import LoanToValueOptions
from zarban.wallet.openapi_client.models.loans_response import LoansResponse
from zarban.wallet.openapi_client.models.loans_response_list import LoansResponseList
from zarban.wallet.openapi_client.models.login_request import LoginRequest
from zarban.wallet.openapi_client.models.network import Network
from zarban.wallet.openapi_client.models.payment import Payment
from zarban.wallet.openapi_client.models.payment_request import PaymentRequest
from zarban.wallet.openapi_client.models.phone_otp_submit_request import PhoneOtpSubmitRequest
from zarban.wallet.openapi_client.models.profile_response import ProfileResponse
from zarban.wallet.openapi_client.models.redemption import Redemption
from zarban.wallet.openapi_client.models.redemption_request import RedemptionRequest
from zarban.wallet.openapi_client.models.redemption_response import RedemptionResponse
from zarban.wallet.openapi_client.models.referral import Referral
from zarban.wallet.openapi_client.models.referral_response import ReferralResponse
from zarban.wallet.openapi_client.models.repay_loan_request import RepayLoanRequest
from zarban.wallet.openapi_client.models.sign_up_request import SignUpRequest
from zarban.wallet.openapi_client.models.simple_response import SimpleResponse
from zarban.wallet.openapi_client.models.swap_request import SwapRequest
from zarban.wallet.openapi_client.models.swap_response import SwapResponse
from zarban.wallet.openapi_client.models.symbol import Symbol
from zarban.wallet.openapi_client.models.task import Task
from zarban.wallet.openapi_client.models.task_response import TaskResponse
from zarban.wallet.openapi_client.models.telegram_profile import TelegramProfile
from zarban.wallet.openapi_client.models.timestamp import Timestamp
from zarban.wallet.openapi_client.models.transaction import Transaction
from zarban.wallet.openapi_client.models.transaction_response import TransactionResponse
from zarban.wallet.openapi_client.models.transaction_status import TransactionStatus
from zarban.wallet.openapi_client.models.transaction_type import TransactionType
from zarban.wallet.openapi_client.models.update_email_request import UpdateEmailRequest
from zarban.wallet.openapi_client.models.update_phone_request import UpdatePhoneRequest
from zarban.wallet.openapi_client.models.user import User
from zarban.wallet.openapi_client.models.user_error import UserError
from zarban.wallet.openapi_client.models.wallet_balance import WalletBalance
from zarban.wallet.openapi_client.models.withdraw_request import WithdrawRequest
from zarban.wallet.openapi_client.models.withdraw_request_body import WithdrawRequestBody
from zarban.wallet.openapi_client.models.withdraw_request_preview import WithdrawRequestPreview
from zarban.wallet.openapi_client.models.withdraw_request_response import WithdrawRequestResponse
from zarban.wallet.openapi_client.models.withdraw_response_body import WithdrawResponseBody




# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class StakePlan(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'plan_name': 'str',
        'contract_address': 'str',
        'apy': 'str',
        'stake_token': 'Token',
        'reward_token': 'Token',
        'finish_at': 'Timestamp'
    }

    attribute_map = {
        'plan_name': 'planName',
        'contract_address': 'contractAddress',
        'apy': 'apy',
        'stake_token': 'stakeToken',
        'reward_token': 'rewardToken',
        'finish_at': 'finishAt'
    }

    def __init__(self, plan_name=None, contract_address=None, apy=None, stake_token=None, reward_token=None, finish_at=None, local_vars_configuration=None):  # noqa: E501
        """StakePlan - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._plan_name = None
        self._contract_address = None
        self._apy = None
        self._stake_token = None
        self._reward_token = None
        self._finish_at = None
        self.discriminator = None

        self.plan_name = plan_name
        self.contract_address = contract_address
        self.apy = apy
        self.stake_token = stake_token
        self.reward_token = reward_token
        self.finish_at = finish_at

    @property
    def plan_name(self):
        """Gets the plan_name of this StakePlan.  # noqa: E501

        Name of staking plan  # noqa: E501

        :return: The plan_name of this StakePlan.  # noqa: E501
        :rtype: str
        """
        return self._plan_name

    @plan_name.setter
    def plan_name(self, plan_name):
        """Sets the plan_name of this StakePlan.

        Name of staking plan  # noqa: E501

        :param plan_name: The plan_name of this StakePlan.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and plan_name is None:  # noqa: E501
            raise ValueError("Invalid value for `plan_name`, must not be `None`")  # noqa: E501

        self._plan_name = plan_name

    @property
    def contract_address(self):
        """Gets the contract_address of this StakePlan.  # noqa: E501

        Ethereum address of the staking contract  # noqa: E501

        :return: The contract_address of this StakePlan.  # noqa: E501
        :rtype: str
        """
        return self._contract_address

    @contract_address.setter
    def contract_address(self, contract_address):
        """Sets the contract_address of this StakePlan.

        Ethereum address of the staking contract  # noqa: E501

        :param contract_address: The contract_address of this StakePlan.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and contract_address is None:  # noqa: E501
            raise ValueError("Invalid value for `contract_address`, must not be `None`")  # noqa: E501

        self._contract_address = contract_address

    @property
    def apy(self):
        """Gets the apy of this StakePlan.  # noqa: E501

        Annual percentage yield of the staking plan  # noqa: E501

        :return: The apy of this StakePlan.  # noqa: E501
        :rtype: str
        """
        return self._apy

    @apy.setter
    def apy(self, apy):
        """Sets the apy of this StakePlan.

        Annual percentage yield of the staking plan  # noqa: E501

        :param apy: The apy of this StakePlan.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and apy is None:  # noqa: E501
            raise ValueError("Invalid value for `apy`, must not be `None`")  # noqa: E501

        self._apy = apy

    @property
    def stake_token(self):
        """Gets the stake_token of this StakePlan.  # noqa: E501


        :return: The stake_token of this StakePlan.  # noqa: E501
        :rtype: Token
        """
        return self._stake_token

    @stake_token.setter
    def stake_token(self, stake_token):
        """Sets the stake_token of this StakePlan.


        :param stake_token: The stake_token of this StakePlan.  # noqa: E501
        :type: Token
        """
        if self.local_vars_configuration.client_side_validation and stake_token is None:  # noqa: E501
            raise ValueError("Invalid value for `stake_token`, must not be `None`")  # noqa: E501

        self._stake_token = stake_token

    @property
    def reward_token(self):
        """Gets the reward_token of this StakePlan.  # noqa: E501


        :return: The reward_token of this StakePlan.  # noqa: E501
        :rtype: Token
        """
        return self._reward_token

    @reward_token.setter
    def reward_token(self, reward_token):
        """Sets the reward_token of this StakePlan.


        :param reward_token: The reward_token of this StakePlan.  # noqa: E501
        :type: Token
        """
        if self.local_vars_configuration.client_side_validation and reward_token is None:  # noqa: E501
            raise ValueError("Invalid value for `reward_token`, must not be `None`")  # noqa: E501

        self._reward_token = reward_token

    @property
    def finish_at(self):
        """Gets the finish_at of this StakePlan.  # noqa: E501


        :return: The finish_at of this StakePlan.  # noqa: E501
        :rtype: Timestamp
        """
        return self._finish_at

    @finish_at.setter
    def finish_at(self, finish_at):
        """Sets the finish_at of this StakePlan.


        :param finish_at: The finish_at of this StakePlan.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and finish_at is None:  # noqa: E501
            raise ValueError("Invalid value for `finish_at`, must not be `None`")  # noqa: E501

        self._finish_at = finish_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StakePlan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StakePlan):
            return True

        return self.to_dict() != other.to_dict()
